CHANGES
===============
1.0.0

- first version

1.0.6

- support ```<hr/>``` in table

1.2.0

- support align attribute in ```<text>``` node with ImageDrawPrint

1.3.0

- EscPosPrint auto convert zh-hant to zh-hans when encode with gbk or gb2312.
- EscPosPrint ignore encode error.